@@ -34,7 +34,9 @@ def sign(name, date, a_hash, position, in_file):
 
 
     signed_page = PyPDF2.PdfFileReader(signed_page_bytes).getPage(0)
-    (page_width, page_height) = page_media.upperRight
+    (page_first_dim, page_second_dim) = page_media.upperRight
+    page_width = page_first_dim if page_second_dim > page_first_dim else page_second_dim
+    page_height = page_second_dim if page_second_dim > page_first_dim else page_first_dim
     signed_page.scaleTo(float(page_width), float(page_height))
 
     output_signed_pdf = PyPDF2.PdfFileWriter()
